beme.alpha.core

beme public API: read and print beme syntax.

Three tracks: text-to-form: beme->forms, forms->beme (all platforms) form-to-text: forms->clj (all platforms), clj->forms (JVM only) text-to-text: beme->clj (all platforms), clj->beme (JVM only)

Pipeline: beme.alpha.pipeline/run — full ctx->ctx pipeline with intermediate state

beme public API: read and print beme syntax.

Three tracks:
  text-to-form:  beme->forms, forms->beme (all platforms)
  form-to-text:  forms->clj (all platforms), clj->forms (JVM only)
  text-to-text:  beme->clj (all platforms), clj->beme (JVM only)

Pipeline:
  beme.alpha.pipeline/run — full ctx->ctx pipeline with intermediate state
raw docstring

beme->cljclj/s

(beme->clj beme-src)
(beme->clj beme-src opts)

Convert beme source string to Clojure source string. opts map: same as beme->forms (e.g. :resolve-keyword).

Convert beme source string to Clojure source string.
opts map: same as beme->forms (e.g. :resolve-keyword).
sourceraw docstring

beme->formsclj/s

(beme->forms s)
(beme->forms s opts)

Read beme source string, return a vector of Clojure forms. opts map: :resolve-keyword — fn that resolves auto-resolve keyword strings ("::foo") to keywords at read time. Required on CLJS (errors without it, since cljs.reader cannot resolve :: correctly). Note: returns only parsed forms. Use run-pipeline when you need access to intermediate pipeline state (raw tokens, grouped tokens).

Read beme source string, return a vector of Clojure forms.
opts map:
  :resolve-keyword — fn that resolves auto-resolve keyword strings ("::foo")
                     to keywords at read time. Required on CLJS (errors
                     without it, since cljs.reader cannot resolve :: correctly).
Note: returns only parsed forms. Use run-pipeline when you need
access to intermediate pipeline state (raw tokens, grouped tokens).
sourceraw docstring

clj->bemeclj

(clj->beme clj-src)

Convert Clojure source string to beme source string. JVM/Babashka only.

Convert Clojure source string to beme source string.
JVM/Babashka only.
sourceraw docstring

clj->formsclj

(clj->forms clj-src)

Read Clojure source string, return a vector of forms. JVM/Babashka only — Clojure's reader is needed for full form support.

Read Clojure source string, return a vector of forms.
JVM/Babashka only — Clojure's reader is needed for full form support.
sourceraw docstring

forms->bemeclj/s

(forms->beme forms)

Print Clojure forms as beme source string (single-line per form).

Print Clojure forms as beme source string (single-line per form).
sourceraw docstring

forms->cljclj/s

(forms->clj forms)

Print Clojure forms as Clojure source string.

Print Clojure forms as Clojure source string.
sourceraw docstring

pprint-bemeclj/s

(pprint-beme forms)
(pprint-beme forms opts)

Pretty-print Clojure forms as beme source string (multi-line, indented). opts: {:width 80}

Pretty-print Clojure forms as beme source string (multi-line, indented).
opts: {:width 80}
sourceraw docstring

run-pipelineclj/s

(run-pipeline source)
(run-pipeline source opts)

Run the full pipeline: source → scan → group → parse. Returns a context map with :source, :opts, :raw-tokens, :tokens, :forms. Useful for tooling that needs intermediate pipeline state.

Run the full pipeline: source → scan → group → parse.
Returns a context map with :source, :opts, :raw-tokens, :tokens, :forms.
Useful for tooling that needs intermediate pipeline state.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries