All platforms.

beme.alpha.runtime.repl

beme REPL: read beme, eval as Clojure, print result.

beme REPL: read beme, eval as Clojure, print result.
raw docstring

input-stateclj/s

(input-state s)
(input-state s opts)

Returns :complete, :incomplete, or :invalid for the given input string. :complete — parsed successfully :incomplete — unclosed delimiter (EOF-related error), keep reading :invalid — malformed literal or other non-recoverable error opts are the same reader opts passed to pipeline/run (e.g. :resolve-keyword) so that the completeness check uses the same reader configuration as eval.

Returns :complete, :incomplete, or :invalid for the given input string.
:complete   — parsed successfully
:incomplete — unclosed delimiter (EOF-related error), keep reading
:invalid    — malformed literal or other non-recoverable error
opts are the same reader opts passed to pipeline/run (e.g. :resolve-keyword)
so that the completeness check uses the same reader configuration as eval.
sourceraw docstring

startclj/s

(start)
(start opts)

Start the beme REPL. Reads beme syntax, evals as Clojure, prints results. opts: :read-line — custom line reader fn (default: read-line; required on CLJS) :eval — custom eval fn (default: eval; required on CLJS) :resolve-keyword — fn to resolve :: keywords at read time (default: clojure.core/read-string on JVM; required on CLJS for code that uses :: keywords)

Start the beme REPL. Reads beme syntax, evals as Clojure, prints results.
opts:
  :read-line       — custom line reader fn (default: read-line; required on CLJS)
  :eval            — custom eval fn (default: eval; required on CLJS)
  :resolve-keyword — fn to resolve :: keywords at read time
                     (default: clojure.core/read-string on JVM; required on CLJS
                     for code that uses :: keywords)
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries