All platforms.

beme.alpha.runtime.run

Run .beme files: read, eval, return last result.

Run .beme files: read, eval, return last result.
raw docstring

run-fileclj/s

(run-file path)
(run-file path eval-fn-or-opts)

Read and eval a .beme file. Returns the last result. Second arg can be an eval-fn (backward compat) or an opts map.

Read and eval a .beme file. Returns the last result.
Second arg can be an eval-fn (backward compat) or an opts map.
sourceraw docstring

run-stringclj/s

(run-string s)
(run-string s eval-fn-or-opts)

Read beme source string, eval each form, return the last result. Strips shebang lines from source before parsing. opts: :eval — eval fn (default: eval; required on CLJS) :resolve-keyword — fn to resolve :: keywords at read time (default: none — :: keywords resolve at eval time in the file's declared namespace. Required on CLJS for code that uses :: keywords)

Read beme source string, eval each form, return the last result.
Strips shebang lines from source before parsing.
opts:
  :eval            — eval fn (default: eval; required on CLJS)
  :resolve-keyword — fn to resolve :: keywords at read time
                     (default: none — :: keywords resolve at eval time
                     in the file's declared namespace. Required on CLJS
                     for code that uses :: keywords)
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries