Pretty-printer: Clojure forms → idiomatic multi-line beme text. Width-aware — uses begin/end for forms that don't fit on one line.
Pretty-printer: Clojure forms → idiomatic multi-line beme text. Width-aware — uses begin/end for forms that don't fit on one line.
(pprint-form form)(pprint-form form opts)Pretty-print a single Clojure form as beme text. Preserves comments from :ws metadata. opts: {:width 80}
Pretty-print a single Clojure form as beme text.
Preserves comments from :ws metadata.
opts: {:width 80}(pprint-forms forms)(pprint-forms forms opts)Pretty-print a sequence of Clojure forms as beme text, separated by blank lines. Preserves comments from :ws metadata. opts: {:width 80}
Pretty-print a sequence of Clojure forms as beme text,
separated by blank lines. Preserves comments from :ws metadata.
opts: {:width 80}cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |