Shared form-level predicates and constructors. Cross-stage contracts that both the parser and printer depend on.
Shared form-level predicates and constructors. Cross-stage contracts that both the parser and printer depend on.
(deferred-auto-keyword raw)Wrap a :: keyword string as a deferred eval form. Returns (clojure.core/read-string "::foo").
Wrap a :: keyword string as a deferred eval form. Returns (clojure.core/read-string "::foo").
(deferred-auto-keyword-raw form)Extract the raw :: keyword string from a deferred form. Caller must check deferred-auto-keyword? first.
Extract the raw :: keyword string from a deferred form. Caller must check deferred-auto-keyword? first.
(deferred-auto-keyword? form)Is form a deferred auto-resolve keyword produced by the reader?
Is form a deferred auto-resolve keyword produced by the reader?
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |